| compute_qoi_user | R Documentation |
Compute Quantities of Interest (GATE, GATEcv, URATE) with user defined functions
compute_qoi_user(user_hte, Tcv, Ycv, data, ngates, ...)
user_hte |
A user-defined function to estimate heterogeneous treatment effects (HTE). The function should take the data as input and return an unit-level continuous score for treatment assignment. We assume those that have score less than 0 should not have treatment. The default is |
Tcv |
A vector of the unit-level binary treatment. |
Ycv |
A vector of the unit-level continuous outcome. |
data |
A data frame containing the variables of interest. |
ngates |
The number of gates to be used in the GATE function. |
... |
Additional arguments to be passed to the user-defined function. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.