plot_CI: Plot Confidence Intervals

View source: R/hte_plot.R

plot_CIR Documentation

Plot Confidence Intervals

Description

A generic function to plot uniform and pointwise confidence intervals for HTE objects.

Usage

plot_CI(x, ...)

Arguments

x

An object for which a plot is desired.

...

Further arguments passed to methods.

Value

A ggplot2 object displaying uniform and pointwise confidence intervals for heterogeneous treatment effects.


evalHTE documentation built on Feb. 3, 2026, 9:07 a.m.