summary.hte: Summarize Heterogeneity and Consistency Tests

View source: R/hte_summary.R

summary.hteR Documentation

Summarize Heterogeneity and Consistency Tests

Description

Summarize Heterogeneity and Consistency Tests

Usage

## S3 method for class 'hte'
summary(object, ...)

Arguments

object

An object of evaluate_hte class (typically an output of evaluate_hte() function).

...

Other parameters.

Value

An object of class summary.hte, which is a list containing:

GATE

A tibble with group average treatment effect estimates, including columns: group, algorithm, estimate, std.deviation, lower, upper, z.score, and p.value.

URATE

A tibble with uplift rate estimates for exceptional responders, including columns: algorithm, estimate, std.deviation, conf.low.uniform, z.score, and p.value. Returns NULL when cross-validation is used.


evalHTE documentation built on Feb. 3, 2026, 9:07 a.m.