| URATE | R Documentation |
This function use individualized treatment rule to identify exceptional responders. The details of the methods for this design are given in Imai and Li (2023).
URATE(D, tau, Y)
D |
A vector of the unit-level binary treatment receipt variable for each sample. |
tau |
A vector of the unit-level continuous score. Conditional Average Treatment Effect is one possible measure. |
Y |
A vector of the outcome variable of interest for each sample. |
A list that contains the following items:
rate |
The estimated
vector of URATE of length |
sd |
The estimated vector of standard deviation of URATE. |
Michael Lingzhi Li, Technology and Operations Management, Harvard Business School mili@hbs.edu, https://www.michaellz.com/;
Imai and Li (2022). “Statistical Inference for Heterogeneous Treatment Effects Discovered by Generic Machine Learning in Randomized Experiments”,
D <- c(1, 0, 1, 0, 1, 0, 1, 0)
tau <- c(0, 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7)
Y <- c(4, 5, 0, 2, 4, 1, -4, 3)
ratelist <- URATE(D, tau, Y)
ratelist$rate
ratelist$sd
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.