| plot_CI | R Documentation |
A generic function to plot uniform and pointwise confidence intervals for HTE objects.
plot_CI(x, ...)
x |
An object for which a plot is desired. |
... |
Further arguments passed to methods. |
A ggplot2 object displaying uniform and pointwise confidence intervals for heterogeneous treatment effects.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.