| summary.hte | R Documentation |
Summarize Heterogeneity and Consistency Tests
## S3 method for class 'hte'
summary(object, ...)
object |
An object of |
... |
Other parameters. |
An object of class summary.hte, which is a list containing:
A tibble with group average treatment effect estimates, including columns: group, algorithm, estimate, std.deviation, lower, upper, z.score, and p.value.
A tibble with uplift rate estimates for exceptional responders, including columns: algorithm, estimate, std.deviation, conf.low.uniform, z.score, and p.value. Returns NULL when cross-validation is used.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.